time_index_unit

Function time_index_unit 

fn time_index_unit(metadata: &RegionMetadataRef) -> Result<TimeUnit>
Returns the unit of the region’s timestamp time index; the writer stamps it into index files so a searcher interprets each file in the unit it was written with (the region’s time index unit may have been widened since).